0.2 (2019-07-08)
----------------

- Updated package layout to use setup.cfg, setuptools_scm, and tox. [#4]

- Fixed compatibility with latest version of glue. [#4]

0.1 (2017-09-05)
----------------

- Initial release
